package example;

import org.apache.commons.httpclient.HttpClient;
import org.apache.commons.httpclient.methods.GetMethod;
import org.apache.commons.httpclient.protocol.Protocol;
import org.apache.jmeter.protocol.http.util.SlowHttpClientSocketFactory;

import java.io.IOException;

public class SlowConnectionSample {
    /*
    http://jmeter.512774.n5.nabble.com/Is-jmeter-can-be-used-to-simulate-network-bandwidth-td533487.html
    To emulate a bandwidth of, say 100 kbps, define a CPS of
    ( 100 * 1024 ) / 8, i.e. 100kB divided by 8, so, that would be
    httpclient.socket.http.cps=12800.

    @param kbpsRate, rate in *kilobits per second*
     */
    private static int calculateBandwidth(int kbpsRate) throws Exception {
        if (kbpsRate <= 0)
            throw new IllegalArgumentException("Rate (kbps) <= 0");

        return (kbpsRate * 1024) / 8;
    }

    public static void main(String args[]) throws Exception {

        /*
        Only the first call goes through the slow connection factory
         */
        int cps = SlowConnectionSample.calculateBandwidth(2);
        for (int i = 0; i < 2; i++) {
            if (0 == i)
                Protocol.registerProtocol("http", new Protocol("http", new SlowHttpClientSocketFactory(cps), 80));
            HttpClient httpClient = new HttpClient();
            GetMethod httpGet = new GetMethod("http://www.google.com");

            try {
                long timerBefore = System.currentTimeMillis();
                httpClient.executeMethod(httpGet);
                long timerAfter = System.currentTimeMillis();

                System.out.println("Call #" + i + "\tResponse: " + httpGet.getStatusLine() + "\tLatency: " + (double) (timerAfter - timerBefore) / 1000 + " sec.");
            } catch (IOException e) {
                System.out.println("Error: " + e.getMessage());
            } finally {
                httpGet.releaseConnection();
            }
            if (0 == i)
                Protocol.unregisterProtocol("http");
        }
    }
}